#!/usr/bin/perl
###########################################################################
# Copyright 2003-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################

# Reads the day cpumem statistic files and puts it into the NEMO database.
#
# Usage:
# -verbose         turns on additional output
# -dir <directory> gives the full path to a spesific directory to be read
# -gatherall       processes all available files
#
# If no -dir parameter is given, it defaults to the directory for this month.
#
# By Gunnar Gauslaa Bergem, June 2003

use strict;
require "nemo_db.pl";
require "timelocal.pl";

my $year_dir ='/local/net-status/data/cpumem/report';
my $net = 'uninett';
my $dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$dbh) {die "Error: Can not connect to database."}

my @busyper_avg;
my @busyper_peak;
my @avgbusy1_avg;
my @avgbusy1_peak;
my @avgbusy5_avg;
my @avgbusy5_peak;

my $s_busyper_avg;
my $s_busyper_peak;
my $s_avgbusy1_avg;
my $s_avgbusy1_peak;
my $s_avgbusy5_avg;
my $s_avgbusy5_peak;

# parse current date to correspond to a cpumem dir
my @lt = localtime(time()-(3600*24));
my $month = @lt[4]+1;
my $year = @lt[5]+1900;
if ($month < 10) { $month = "0$month"; }
my $datestring = "$year/months/$month";

opendir(YEAR_DIR, $year_dir) or die $!;
my @years = readdir(YEAR_DIR);
closedir(YEAR_DIR);

my $inserted_records = 0;
my $skipped_records = 0;
my $updated_records = 0;

# initialize command-line parameters
my $dirname = "$year_dir/$datestring";
my $gather_all = 0;
my $verbose = 0;

my @dirs;
my $year;
my $month;

while ($#ARGV >= 0) {
    if ($ARGV[0] =~ /-verbose/) {
	shift(@ARGV);
	$verbose = 1;
    }    
    elsif ($ARGV[0] =~ /-dir/) {
        shift(@ARGV);
        $dirname = shift(@ARGV);
	push(@dirs, $dirname);
	$gather_all = 1;  # if a directory is supplied, read the whole thing 
    }
    elsif ($ARGV[0] =~ /-gatherall/) {
        shift(@ARGV);
	opendir(YEAR_DIR, $year_dir) or die $!;
	my @years = readdir(YEAR_DIR);
	closedir(YEAR_DIR);
	foreach $year (@years) {
	    opendir(MONTH_DIR, "$year_dir/$year/months");
	    foreach $month (readdir MONTH_DIR) {
		push(@dirs, "$year_dir/$year/months/$month");
	    }
	    closedir(MONTH_DIR);
	}
	$gather_all = 1;
    }
    else {
        shift(@ARGV);
    }
}

if ($#dirs < 0) {
    # no dirs supplied in command-line arguments, use default (yesterdays) dir
    push(@dirs, $dirname);
}

my $file;
my $dir;
my $sth;

foreach $dir (@dirs) {
    if ($dir =~ /\/local\/net-status\/data\/cpumem\/report\/(\d+)\/months\/(\d+)/) {
	$year = $1;
	$month = $2;
    }
    print "Opening dir $dir\n" if $verbose;
    opendir(CPU_DIR, $dir) or die $!;
    my @files = readdir(CPU_DIR);
    closedir(CPU_DIR);
        
    foreach $file (@files) {
	if ($file eq '.' or $file eq '..') { next; }
        
	open(CPU_FILE, "$dir/$file") or die $!;
	my @file_elements = split /\./, $file;
	my $eq_name = $file_elements[0];
	my $line;
	
	$sth = $dbh->prepare("SELECT eq_id, location_id FROM equipment WHERE eq_id = '$eq_name.uninett.no'");
	$sth->execute();
	my $row = $sth->fetchrow_hashref();
	my $eq_id = $row->{eq_id};
	my $loc_id = $row->{location_id};
	$sth->finish();

	if (!defined $eq_id) { next; }
	print "Reading statistics for $eq_id\n" if $verbose;
	while (defined ($line = <CPU_FILE>)) {
	    if ($line =~ /avgBusy1\.average\s(.+)/) {
		@avgbusy1_avg = split /\s+/, $1;
	    }
	    elsif ($line =~ /avgBusy1\.peak\s(.+)/) {
		@avgbusy1_peak = split /\s+/, $1;
	    }
	    elsif ($line =~ /avgBusy5\.average\s(.+)/) {
		@avgbusy5_avg = split /\s+/, $1;
	    }
	    elsif ($line =~ /avgBusy5\.peak\s(.+)/) {
		@avgbusy5_peak = split /\s+/, $1;
	    }
	    elsif ($line =~ /busyPer\.average\s(.+)/) {
		@busyper_avg = split /\s+/, $1;
	    }
	    elsif ($line =~ /busyPer\.peak\s(.+)/) {
		@busyper_peak = split /\s+/, $1;
	    }
	}
	my $num_days = 0;
	my $statvalue;

	for $statvalue (@busyper_peak) {
	    $num_days++;
            my $NA = 0;
	    my $timestamp = timelocal(0, 0, 12, $num_days, $month-1, $year);
	    
	    if (!$avgbusy1_peak[$num_days-1] || $avgbusy1_peak[$num_days-1] eq "N/A") {
		$s_avgbusy1_peak = 0;
		$NA = 1;
	    }
	    else {
		$s_avgbusy1_peak = int($avgbusy1_peak[$num_days-1]);
	    }
	    
	    if (!$avgbusy1_avg[$num_days-1] || $avgbusy1_avg[$num_days-1] eq "N/A") {
		$s_avgbusy1_avg = 0;
		$NA = 1;
	    }
	    else {
		$s_avgbusy1_avg = int($avgbusy1_avg[$num_days-1]);
	    }
	    
	    if (!$avgbusy5_peak[$num_days-1] || $avgbusy5_peak[$num_days-1] eq "N/A") {
		$s_avgbusy5_peak = 0;
		$NA = 1;
	    }
	    else {
		$s_avgbusy5_peak = int($avgbusy5_peak[$num_days-1]);
	    }
                        
	    if (!$avgbusy5_avg[$num_days-1] || $avgbusy5_avg[$num_days-1] eq "N/A") {
		$s_avgbusy5_avg = 0;
		$NA = 1;
	    }
	    else {
		$s_avgbusy5_avg = int($avgbusy5_avg[$num_days-1]);
	    }
	    
	    if (!$busyper_peak[$num_days-1] || $busyper_peak[$num_days-1] eq "N/A") {
		$s_busyper_peak = 0;
		$NA = 1;
	    }
	    else {
		$s_busyper_peak = int($busyper_peak[$num_days-1]);
	    }
	    
	    if (!$busyper_avg[$num_days-1] || $busyper_avg[$num_days-1] eq "N/A") {
		$s_busyper_avg = 0;
		$NA = 1;
	    }
	    else {
		$s_busyper_avg = int($busyper_avg[$num_days-1]);
	    }
	    
            if ($NA == 1) { next; }  # skip to next element if we get undefined values

	    $sth = $dbh->prepare("SELECT point_id, five_sec_load_peak, five_sec_load_avg, one_min_load_peak, ".
				 "one_min_load_avg, five_min_load_peak, five_min_load_avg FROM point_cpuload_day WHERE ".
				 "point_id = (SELECT location_id FROM equipment WHERE eq_id = '$eq_id') AND timestamp ".
				 "= $timestamp");
	    $sth->execute();
	    my $row = $sth->fetchrow_hashref();
	    my $point_id = $row->{point_id};
	    my $point_five_sec_peak = $row->{five_sec_load_peak};
	    my $point_five_sec_avg = $row->{five_sec_load_avg};
	    my $point_one_min_peak = $row->{one_min_load_peak};
	    my $point_one_min_avg = $row->{one_min_load_avg};
	    my $point_five_min_peak = $row->{five_min_load_peak};
	    my $point_five_min_avg = $row->{five_min_load_avg};
	    $sth->finish();

	    if (defined $point_id) {
		$point_five_sec_peak = $s_busyper_peak if ($s_busyper_peak > $point_five_sec_peak);
		$point_five_sec_avg = $s_busyper_avg if ($s_busyper_avg > $point_five_sec_avg);
		$point_one_min_peak = $s_avgbusy1_peak if ($s_avgbusy1_peak > $point_one_min_peak);
		$point_one_min_avg = $s_avgbusy1_avg if ($s_avgbusy1_avg > $point_one_min_avg);
		$point_five_min_peak = $s_avgbusy5_peak if ($s_avgbusy5_peak > $point_five_min_peak);
		$point_five_min_avg = $s_avgbusy5_avg if ($s_avgbusy5_avg > $point_five_min_avg);
		
		$sth = $dbh->prepare("UPDATE point_cpuload_day SET five_sec_load_peak = $point_five_sec_peak, ".
				     "five_sec_load_avg = $point_five_sec_avg, one_min_load_peak = $point_one_min_peak, ".
				     "one_min_load_avg = $point_one_min_avg, five_min_load_peak = $point_five_min_peak, ".
				     "five_min_load_avg = $point_five_min_avg WHERE point_id = $point_id AND timestamp = $timestamp");
		$sth->execute();
                $sth->finish();
		$updated_records++;
	    }
	    else {
		$sth = $dbh->prepare("SELECT location_id FROM equipment WHERE eq_id = '$eq_id'");
		$sth->execute();
		$point_id = ($sth->fetchrow_array())[0];
                $sth->finish();
		if (defined $point_id) {
		    $sth = $dbh->prepare("INSERT INTO point_cpuload_day VALUES ($point_id, $timestamp, ".
					 "$s_busyper_peak, $s_busyper_avg, $s_avgbusy1_peak, $s_avgbusy1_avg, ".
					 "$s_avgbusy5_peak, $s_avgbusy5_avg)");
		    $sth->execute();
                    $sth->finish();
		    $inserted_records++;
		}
	    }
	    
	    $sth = $dbh->prepare("SELECT eq_id FROM eq_cpuload_day WHERE eq_id = '$eq_id' AND timestamp = '$timestamp'");
	    $sth->execute();
	    my $db_eq_id = ($sth->fetchrow_array())[0];
            $sth->finish();	    

	    if (!defined $db_eq_id) {
		$sth = $dbh->prepare("INSERT INTO eq_cpuload_day VALUES ".
				     "('$eq_id', $timestamp, $s_busyper_peak, $s_busyper_avg, ".
				     "$s_avgbusy1_peak, $s_avgbusy1_avg, $s_avgbusy5_peak, $s_avgbusy5_avg)");
		$sth->execute();
                $sth->finish();
		$inserted_records++;
	    }
	    else {
	        $skipped_records++;
	    }
	}
    }
}

print "Inserted records: $inserted_records   Updated records: $updated_records   Skipped records: $skipped_records\n" if $verbose;

$dbh->disconnect();
