#!/usr/bin/perl
###########################################################################
# Copyright 2003-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################

# Reads all the .ko.luk files with lines and points and puts
# it into the NEMO database.
# By Gunnar Gauslaa Bergem, June 2003

use strict;

require "nemo_db.pl";

my $coord_dir = '/kart/uninett/geo/ko/';

opendir (COORD_DIR, $coord_dir) or die $!;
my @files = readdir(COORD_DIR);
closedir(COORD_DIR);

my $net = 'uninett';
my $dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$dbh) {die "Error: Can not connect to database."}

my $file;
my $sth;

my $verbose = 0;

while ($#ARGV >= 0) {
    if ($ARGV[0] =~ /-verbose/) {
	shift(@ARGV);
	$verbose = 1;
    }
    else {
	shift(@ARGV);
    }
}

my $extrafile = '/kart/uninett/geo/ekstra/nordunet.ko';
push @files, $extrafile;

# set all the to_dates for points and lines to the current date
my $now = time();
$sth = $dbh->prepare("UPDATE map_point SET to_date = '$now' WHERE to_date = -1 AND net = '$net'");
$sth->execute();
$sth = $dbh->prepare("UPDATE map_line SET to_date = '$now' WHERE to_date = -1 AND net = '$net'");
$sth->execute();

foreach $file (@files) {
    my $mapname;
    
    # nordunet gets special treatment since its not together with the rest of the files
    if ($file =~ /(\w+-?\d?).ko.luk/ or $file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	if ($file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	    $mapname = 'norden';
	}
	else {
	    $mapname = $1;
	}
	print ("map: $mapname\n") if $verbose;

	if ($file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	    open (COORD_FILE, $file) or die $!;
	}
	else {
	    # open a .ko.luk file
	    open (COORD_FILE, "$coord_dir/$file") or die $!;
	}
	my $line;
	while (defined ($line = <COORD_FILE>)) {
	    if ($line =~ /^PUNKT\s+(\w+)\s+(\w+)\s+(\d+)\s+(\d+)\s+(-?\d+)/) {
		my $pointtype = $1;  # type of point, like 'sted' or 'satelitt'
		my $pointname = $2;  # name of the point
		my $utm_zone = "UTM-$3";  # UTM zone
		my $utm_y1 = $4;  # UTM north coord
		my $utm_x1 = $5;  # UTM east coord

		# check if it already exists a point with the same name in the network
		$sth = $dbh->prepare("SELECT location_id FROM location WHERE net = '$net' AND location_name = '$pointname'");
		$sth->execute();
		my $location_id = ($sth->fetchrow_array())[0];
		if ($pointtype eq 'sted' or ($pointtype eq 'satelitt' and $mapname eq 'norden')) {
		    if (!defined $location_id) {
		        # enter a new 'sted' into the database using the current date as starting date
		        print ("Inserting pointname: $pointname  pointtype: $pointtype  utm_zone: $utm_zone  utm_y1: $utm_y1  utm_x1: $utm_x1\n");
		        $sth = $dbh->prepare("INSERT INTO location (net, location_name) VALUES ".
					     "('$net', '$pointname')");
		        $sth->execute();
                        $sth = $dbh->prepare("INSERT INTO map_point (net, map_id, location_id, point_type, from_date, to_date, x, y, coord_type) ".
                                             "VALUES ('$net', '$mapname', '$location_id', '$pointtype', $now, -1, $utm_x1, $utm_y1, '$utm_zone')");
                        $sth->execute();
		    }
		}
                if (defined $location_id) {
                    $sth = $dbh->prepare("SELECT COUNT(*) FROM map_point WHERE net = '$net' AND map_id = '$mapname' ".
                                         "AND location_id = '$location_id'");
                    $sth->execute();
                    my $map_point_entry = ($sth->fetchrow_array())[0];
                    $sth = $dbh->prepare("SELECT COUNT(*) FROM map WHERE net = '$net' AND map_id = '$mapname'");
                    $sth->execute();
                    my $map_entry = ($sth->fetchrow_array())[0];
                    # check if there is no entry in the map_point table and if the map exists in the database
                    if ($map_point_entry == 0 && $map_entry != 0) {
		        # enter the relation between the point and the map in the map_point table
		        $sth = $dbh->prepare("INSERT INTO map_point (net, map_id, location_id, point_type, from_date, to_date, x, y, coord_type) ".
                                             "VALUES ('$net', '$mapname', '$location_id', '$pointtype', $now, -1, $utm_x1, $utm_y1, '$utm_zone')");
		        $sth->execute();
                    }
                    elsif ($map_point_entry > 0) {
                        # the location is both in the .ko.luk file and the database, set its to_date to -1 (infinity)
                        $sth = $dbh->prepare("UPDATE map_point SET to_date = -1 WHERE location_id = '$location_id' AND net = '$net' ".
                                             "AND map_id = '$mapname'");
                        $sth->execute();
                    }
                }
	    }
	}
	close (COORD_FILE);

	if ($file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	    open (COORD_FILE, $file) or die $!;
	}
	else {
	    open (COORD_FILE, "$coord_dir/$file") or die $!;
	}
	while (defined ($line = <COORD_FILE>)) {
	    # check for 'sky' entries in the file
	    if ($line =~ /^SKY\s+4H\s+(\w+)/) {
		my $pointname = $1;

		# find the location_id of the point corresponding to the 'sky' entry
		$sth = $dbh->prepare("SELECT location_id FROM location WHERE net = '$net' AND location_name = '$pointname'");
		$sth->execute();
		my $location_id = ($sth->fetchrow_array())[0];

		# update the point_type in the map_point to 'sky' in the map_point table
		$sth = $dbh->prepare("UPDATE map_point SET point_type = 'sky' WHERE net = '$net' AND map_id = '$mapname' ".
				     "AND location_id = '$location_id'");
		$sth->execute();
	    }
	}
	close (COORD_FILE);
    }
}

# Now we add all the lines in the same manner as we did with the points
foreach $file (@files) {
    my $mapname;
    if ($file =~ /(\w+-?\d?).ko.luk/ or $file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
        if ($file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	    $mapname = 'norden';
	}
	else {
	    $mapname = $1;
	}
	print ("map: $mapname\n") if $verbose;

	if ($file eq '/kart/uninett/geo/ekstra/nordunet.ko') {
	    open (COORD_FILE, $file) or die $!;
	}
	else {
	    open (COORD_FILE, "$coord_dir/$file") or die $!;
	}
	my $line;
	while (defined ($line = <COORD_FILE>)) {
	    if ($line =~ /^LINJE\s+(\w+)\s+(\S+)\s+(\w+)\s+(\w+)/) {
		my $linetype = $1;
		my $linename = $2;
		my $from_loc = $3;
		my $to_loc = $4;

		$sth = $dbh->prepare("SELECT location_id FROM location WHERE location_name = '$from_loc' AND net = '$net'");
		$sth->execute();
		my $from_loc_id = ($sth->fetchrow_array())[0];

		$sth = $dbh->prepare("SELECT location_id FROM location WHERE location_name = '$to_loc' AND net = '$net'");
		$sth->execute();
		my $to_loc_id = ($sth->fetchrow_array())[0];
                my $line_id;

                if ((defined $from_loc_id) && (defined $to_loc_id)) {
		    $sth = $dbh->prepare("SELECT line_id FROM line WHERE line_name = '$linename' AND from_loc = '$from_loc_id' ".
                                         "AND to_loc = '$to_loc_id'");
		    $sth->execute();
		    $line_id = ($sth->fetchrow_array())[0];
                }
		if (!defined $line_id && defined $from_loc_id && defined $to_loc_id) {
		    print ("Inserting linename: $linename  linetype: $linetype  from: $from_loc_id  to: $to_loc_id\n") if $verbose;
		    $sth = $dbh->prepare("INSERT INTO line (net, line_type, line_name, from_loc, to_loc) VALUES ".
					 "('$net', '$linetype', '$linename', '$from_loc_id', '$to_loc_id')");
		    $sth->execute();
                    $sth = $dbh->prepare("INSERT INTO map_line (net, map_id, line_id, from_date to_date) ".
                                         "VALUES ('$net', '$mapname', '$line_id', $now, -1)");
                    $sth->execute();
		}
                elsif (defined $line_id) {
                    $sth = $dbh->prepare("SELECT COUNT(*) FROM map_line WHERE net = '$net' AND map_id = ".
                                         "'$mapname' AND line_id = '$line_id'");
                    $sth->execute();
                    my $map_line_entry = ($sth->fetchrow_array())[0];
                    $sth = $dbh->prepare("SELECT COUNT(*) FROM map WHERE net = '$net' AND map_id = '$mapname'");
                    $sth->execute();
                    my $map_entry = ($sth->fetchrow_array())[0];
                    if ($map_line_entry == 0 && $map_entry != 0) {
	               $sth = $dbh->prepare("INSERT INTO map_line (net, map_id, line_id, from_date, to_date) ".
                                            "VALUES ('$net', '$mapname', '$line_id', $now, -1)");
	               $sth->execute();
                    }
                    elsif ($map_line_entry > 0) {
                       $sth = $dbh->prepare("UPDATE map_line SET to_date = -1 WHERE line_id = '$line_id' AND ".
                                            "net = '$net' AND map_id = '$mapname'");
                       $sth->execute();
                    }
                }
	    }
	}
        close (COORD_FILE);
    }
}

$sth->finish();
$dbh->disconnect();
