#!/usr/bin/perl
###########################################################################
# Copyright 2003-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################

# Reads the KIND database and finds the bindings between geographic
# places and network equipment.
#
# By Gunnar Gauslaa Bergem, June 2004

use strict;
use Net::hostent;
use Socket;

require "nemo_db.pl";

my $nemo_sth;
my $kind_sth;

my $net = 'uninett';
my $nemo_dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$nemo_dbh) {die "Error: Can not connect to Nemo database."}

my $kind_dsn = 'dbi:Pg:dbname=kind';
my $kind_usr = 'kind_ro';
my $kind_pw;
my $kind_dbh = DBI->connect($kind_dsn, $kind_usr, $kind_pw);
if (!$kind_dbh) {die "Error: Can not connect to Kind database."}

my $verbose = 0;

while ($#ARGV >= 0) {
    if ($ARGV[0] =~ /-verbose/) {
	shift(@ARGV);
	$verbose = 1;
    }
    else {
	shift(@ARGV);
    }
}

$kind_sth = $kind_dbh->prepare("SELECT utstyr.navn, nettinstallasjon.navn FROM utstyr, nettinstallasjon ".
			       "WHERE utstyr.nettinstallasjon = nettinstallasjon.id");
$kind_sth->execute();

while (my @row = $kind_sth->fetchrow_array()) {
    my $eq_id = $row[0];
    my $location = $row[1];

    $nemo_sth = $nemo_dbh->prepare("SELECT location_id FROM location WHERE location_name = '$location'");
    $nemo_sth->execute();
    my $loc_id = ($nemo_sth->fetchrow_array())[0];
    if (!defined $loc_id) {
	print "$location not found in Nemo database, skipping to next entry.\n" if $verbose;
	next;
    }
    my $inner_sth = $nemo_dbh->prepare("SELECT eq_id FROM equipment WHERE eq_id = 'eq_id'");
    $inner_sth->execute();
    my $db_eq = ($inner_sth->fetchrow_array())[0];
    if (defined $db_eq) {
	print "Inserting equipment $eq_id\n" if $verbose;
	$inner_sth = $nemo_dbh->prepare("INSERT INTO equipment (eq_id, net, location_id) ".
					"VALUES ('$eq_id', '$net', $loc_id)");
	$inner_sth->execute();
	
	$inner_sth = $nemo_dbh->prepare("DELETE FROM equipment_address WHERE eq_id = '$eq_id'");
	$inner_sth->execute();
	my $host = gethost("$eq_id");
	my @ip_addresses;
	if (defined $host) {
	    @ip_addresses = @{$host->addr_list};
	}
	if ($#ip_addresses >= 0) {
	    foreach my $address (@ip_addresses) {
		my $parsed_address = inet_ntoa($address);
		$inner_sth = $nemo_dbh->prepare("SELECT ip_address FROM equipment_address WHERE ".
						"eq_id = '$eq_id' AND ip_address = '$parsed_address'");
		$inner_sth->execute();
		my $db_address = ($inner_sth->fetchrow_array())[0];
		if (!defined $db_address) {
		    print "Inserting $eq_id and IP = $parsed_address\n" if $verbose;
		    $inner_sth = $nemo_dbh->prepare("INSERT INTO equipment_address (eq_id, ip_address) ".
						    "VALUES ('$eq_id', '$parsed_address')");
		    $inner_sth->execute();
		}
	    }
	}
    }
}

$kind_sth->finish();
$nemo_sth->finish();
$kind_dbh->disconnect();
$nemo_dbh->disconnect();
