#!/usr/bin/perl
###########################################################################
# Copyright 2003-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################

# Reads the geo.transform file and puts the values into the map table in
# the NEMO database.
#
# Each line is on the following form:
# id;scale;giftrans;gifx;gify;utm_y1;utm_x1;utm_y2;utm_x2;utm_zone;zoomlevel
#
# By Gunnar Gauslaa Bergem, June 2003

use strict;

require "nemo_db.pl";

my $line;
my $sth;

open FILE, '/kart/uninett/geo/ko/geo.transform' or die $!;

my $net = 'uninett-topo';
my $dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$dbh) {die "Error: Can not connect to database."}

my $verbose = 0;

while ($#ARGV >= 0) {
    if ($ARGV[0] =~ /-verbose/) {
	shift(@ARGV);
	$verbose = 1;
    }
    else {
	shift(@ARGV);
    }
}

# First mark all maps with a 'delete' flag
$sth = $dbh->prepare("UPDATE map SET mapurl = 'delete' WHERE net = '$net'");
$sth->execute();

while (defined ($line = <FILE>)) {
    if ($line =~ /(\w+-?\d?);(\d+);(\d+\.\d+);(\d+);(\d+);(\d+);(-?\d+);(\d+);(-?\d+);(\d+);(\d+)/) {
	my $id = $1;   # name of the map, like sogndal-2
	my $scale = $2;
	my $giftrans = $3;
	my $factor = $scale / $giftrans;  # this is the coords per pixel ratio
	my $gifx = $4; # bitmap width
	my $gify = $5; # bitmap height
	my $y1 = $6;   # UTM north coord 1
	my $x1 = $7;   # UTM east coord 1
	my $y2 = $8;   # UTM north coord 2
	my $x2 = $9;   # UTM east coord 2
	my $zone = "UTM-$10";  # UTM zone
	my $zoom = $11;  # Zoomlevel
	my $url = "http://drift.uninett.no/kart/nemo/topo_mapimages/$1.png";  # url that points to the map image in png format
	print "id: $id  gifx: $gifx  gify: $gify  y1: $y1  x1: $x1  y2: $y2  x2: $x2  zone: $zone  zoom: $zoom  factor: $factor\n" if $verbose;
        print "url: $url\n\n" if $verbose;
        $sth = $dbh->prepare("SELECT COUNT(*) FROM map WHERE map_id = '$id' AND net = '$net'");
        $sth->execute();
	my $num_rows = ($sth->fetchrow_array())[0];
	if ($num_rows == 0) {
	    $sth = $dbh->prepare("INSERT INTO map VALUES ('$id', '$net', '$zone', '$gifx', '$gify', '$x1', '$y1', '$x2', '$y2', '$zoom', '$url', '$factor')");
	    $sth->execute();
	}
	else {
	    $sth = $dbh->prepare("UPDATE map SET coord_type = '$zone', bitmap_width = '$gifx', bitmap_height = '$gify', x1 = '$x1', y1 = '$y1', ".
				 "x2 = '$x2', y2 = '$y2', zoomlevel = '$zoom', mapurl = '$url', bitmap_factor = '$factor' WHERE map_id = '$id' ".
                                 "AND net = '$net'");
	    $sth->execute();
	}
    }
}

# Delete the maps that still has the 'delete' flag set, ie those that were not found in the geo.transform file
$sth = $dbh->prepare("DELETE FROM map WHERE mapurl = 'delete' AND net = '$net'");
$sth->execute();

$sth->finish();
$dbh->disconnect();
