#!/usr/bin/perl
###########################################################################
# Copyright 2004-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################

# Reads the line load statistic files and puts it into the NEMO database.
#
# Usage:
# -verbose         turns on additional output
# -file <filename> gives the full path to a spesific file to be read
#
# If no -file parameter is given, it defaults to the file for today.
#
# By Gunnar Gauslaa Bergem, June 2003

use strict;

require "nemo_db.pl";
require "timelocal.pl";

my $net = 'uninett';
my $dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$dbh) {die "Error: Can not connect to database."}

my $sth;
my $line;
my $file;
my @files;

my $inserted_records = 0;
my $skipped_records = 0;

# initialize command-line parameters
my $filename = "/kart/www/uninett/geo/last-nuh/traffic.kbit";
my $verbose = 0;

while ($#ARGV >= 0) {
    if ($ARGV[0] =~ /-verbose/) {
	shift(@ARGV);
	$verbose = 1;
    }    
    elsif ($ARGV[0] =~ /-file/) {
        shift(@ARGV);
        $filename = shift(@ARGV);
	push(@files, $filename);
    }
    else {
        shift(@ARGV);
    }
}

if ($#files < 0) {
    # no files supplied in command-line arguments, use default (todays) file
    push(@files, $filename);
}

foreach $file (@files) {
    open (LOAD_FILE, $file) or die $!;

    my @stats = stat LOAD_FILE;
    my $timestamp = $stats[10];
    
    printf(STDERR "timestamp: $timestamp\n") if $verbose;

    while (defined ($line = <LOAD_FILE>)) {
	if ($line =~ /^([\w#.\/-]+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)/) {
	    my $linename = $1;
	    my $max_in = $2;
	    my $max_out = $3;
	    my $avg_in = $4;
	    my $avg_out = $5;
	    my $capacity = $6;
	    my $percent_in;
	    my $percent_out;
	    my $hr_percent_in;
	    my $hr_percent_out;
	    if ($capacity > 0) {
		$percent_in = int ($max_in * 100 / $capacity);
		$percent_out = int ($max_out * 100 / $capacity);
		$hr_percent_in = int ($avg_in * 100 / $capacity);
		$hr_percent_out = int ($avg_out * 100 / $capacity);
		
		
		$sth = $dbh->prepare("SELECT line_id FROM line WHERE line_name = '$linename'");
		$sth->execute();
		while (my @row = $sth->fetchrow_array()) {
		    # get count of lines with data for 5 min load
		    my $lineid = $row[0];
		    my $inner_sth = $dbh->prepare("SELECT COUNT(*) from line_load_5min WHERE line_id = '$lineid' AND timestamp = '$timestamp'");
		    $inner_sth->execute();
		    my $num_rows = ($inner_sth->fetchrow_array())[0];
		    if ($num_rows > 0) {
			# if timestamp exists, don't attempt to reenter data
			$skipped_records++;
			my $date = get_date($timestamp);
			my $time = get_time($timestamp);	
		    } else {
			$inner_sth = $dbh->prepare("INSERT INTO line_load_5min VALUES ('$lineid', '$timestamp', '$max_in', '$max_out', '$percent_in', ".
						   "'$percent_out', '$capacity')");
			$inner_sth->execute();
			$inserted_records++;
		    }
		}
	    }
	}
    }
}

print "Inserted records: $inserted_records   Skipped records: $skipped_records\n" if $verbose;	
$sth->finish();
$dbh->disconnect();


sub get_date{
    my ($time) = @_;
    my @t = localtime($time);
    $t[5]+=1900;
    $t[4]++;
    
    $t[4] = "0$t[4]" if(length($t[4])==1);
    $t[3] = "0$t[3]" if(length($t[3])==1);
    my $ret = "$t[5]-$t[4]-$t[3]";
}

sub get_time{
    my ($time) = @_;
    my @t = localtime($time);
    my $ret = "$t[2]:$t[1]:$t[0]";
}


