#! /usr/bin/perl 
###########################################################################
# Copyright 2003-2005 UNINETT AS
# http://www.uninett.no
#
# This file is part of Nemo.
#
# Nemo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Nemo is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Nemo; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###########################################################################
#Exports port statistics data for the Stager database into NemoDB
#
#By Simon Jonassen, July 2005
#Based on the script by Gunnar Gauslaa Bergem, June 2004
use strict;

require "nemo_db.pl";
require "timelocal.pl";

my $nemo_sth;
my $netflow_sth;

my $net = 'uninett';
my $nemo_dbh = DBI->connect($NemoDB::dsn, $NemoDB::user, $NemoDB::password);
if (!$nemo_dbh) {die "Error: Can not connect to Nemo database."}

my $netflow_dsn = 'DBI:Pg:dbname=stager;host=netflowdata.uninett.no;port=5433';
my $netflow_usr = 'stager';
my $netflow_pw = 'Stag56er';
my $netflow_dbh = DBI->connect($netflow_dsn, $netflow_usr, $netflow_pw);
if (!$netflow_dbh) {die "Error: Can not connect to Netflow database."}

my %protocols = (
		  "25" => "SMTP mail (port 25)",
		  "80" => "WWW HTTP (port 80)",
		  "4662" => "eMule (port 4662)",
		  "6881" => "BitTorrent (port 6881)",
		  );

# initialize command-line parameters
my $day;
my $fromdate;
my $todate;
my $verbose = 0;
my $debug=0;

while ($#ARGV >= 0) {
   if ($ARGV[0] =~ /-verbose/) {
		shift(@ARGV);
		$verbose = 1;
   }
	elsif ($ARGV[0] =~ /-debug/) {
		shift(@ARGV);
		$debug = 1;
		$verbose = 1;
   }
   elsif ($ARGV[0] =~ /-sttype/) {
       shift(@ARGV);
       my $period = shift(@ARGV);
	if ($period eq "day"){ $day=1; }
	if ($period eq "hour"){ $day=0;}
   }
   elsif ($ARGV[0] =~ /-from/) {
		shift(@ARGV);
		$fromdate = shift(@ARGV);
   }
   elsif ($ARGV[0] =~ /-to/){
    	shift(@ARGV);
		$todate = shift(@ARGV);
   }
   else {
        shift(@ARGV);
		  die "Invalid argument. Usage:\n netflow.sj --from DD.MM.YYYY_HH:MM:SS --to DD.MM.YYYY_HH:MM:SS --sttype (day|hour) [--verbose]";
    }
}
if (!defined $day){ die "Wrong or no -sttype";}

my $futime;
my $tutime;

#initialize period and port type related variables
my $step=3600;
my $interval="01:00:00";
my $str_interval="hour";
my $str_port;
if ($day){
	$step*=24;
	$interval="24:00:00";
	$str_interval="day";
}
if ($fromdate and $todate){
	if ($fromdate =~ /(\d+)\.(\d+)\.(\d+)\_(\d+)\:(\d+)\:(\d+)/) {
		$futime=timelocal(0,0,$4,$1,$2-1,$3);
	}else {die "Wrong start date format!";}
	if ($todate =~ /(\d+)\.(\d+)\.(\d+)\_(\d+)\:(\d+)\:(\d+)/) {
		$tutime=timelocal(0,0,$4,$1,$2-1,$3);
	}else {die "Wrong finish date format!";}
	if ($verbose){ print "Get statistics from $fromdate to $todate, day=$day\n";}
}else{
	#sets time interval to yesterday
	$todate=`date +%D`;
	if ($todate =~ /(\d+)\/(\d+)\/(\d+)/){
		$tutime=timelocal(0,0,0,$2,$1-1,2000+$3);
		$futime=$tutime-24*3600;
	}
	if ($verbose){ print "Get statistics for yesterday, day=$day\n";}
}
print $futime . " til " . $tutime . "\n" if $verbose;

#initialize all other variables
my $skipped_rows = 0;
my $updated_rows = 0;
my $inserted_rows = 0;
my $cur_year;
my $cur_month;
my $cur_date;
my $cur_hour;
my $cur_min;
my $cur_sec;
my $start_timestamp;
my $int_timestamp;
my $time_id;

for ($int_timestamp=$futime; $int_timestamp < $tutime; $int_timestamp+=$step){
	($cur_sec,$cur_min,$cur_hour,$cur_date,$cur_month,$cur_year)=localtime($int_timestamp);
	$cur_month++;
	$cur_year+=1900;
	if ($cur_hour<10){ $cur_hour="0".$cur_hour;}
	if ($cur_date<10){ $cur_date="0".$cur_date;}
	if ($cur_month<10){$cur_month="0".$cur_month;}

	$start_timestamp = "$cur_year-$cur_month-$cur_date $cur_hour:00:00"; 
	print "Fetching starttime = $start_timestamp ($int_timestamp)\n" if $verbose;

	$netflow_sth = $netflow_dbh->prepare("SELECT id FROM timeperiod WHERE starttime = '$start_timestamp' AND interval = '$interval'");
	$netflow_sth->execute();
	$time_id = ($netflow_sth->fetchrow_array())[0];
	$netflow_sth->finish();
	if (!defined $time_id) { next; }
	$str_port="src";
	&getstat;
	$str_port="dst";
	&getstat;
}
print "Skipped rows: $skipped_rows Updated rows: $updated_rows Inserted rows: $inserted_rows\n" if $verbose;
$netflow_dbh->disconnect();
$nemo_dbh->disconnect();

sub getstat{
    while ((my $port_number, my $port_descr) = each %protocols) {
		$netflow_sth = $netflow_dbh->prepare("SELECT descr.name, CASE WHEN tot_octets=0 THEN 0 ELSE (octets*100/tot_octets) END AS p_octets ".
			"FROM $str_port"."_port_$str_interval cur, summary_$str_interval tsum, obs_point_descr descr ".
			"WHERE cur.period_id='$time_id' AND tsum.period_id='$time_id' AND tsum.obs_point = cur.obs_point AND cur.portnr = '$port_number' ".
			"AND descr.obs_point_id =  cur.obs_point");
		$netflow_sth->execute();
		while (my @row = $netflow_sth->fetchrow_array()) {
			my $rev = 0;
			my $line_id;
		   my $line_name = $row[0];
		   my $percent_value = $row[1];
		   my $rev_line_name;
		   if ($line_name =~ /([\w\d]+)-([\w\d]+)/) {
				$rev_line_name = "$2"."-"."$1";
			}
		   $nemo_sth = $nemo_dbh->prepare("SELECT line_id FROM line WHERE line_name = '$line_name'");
		   $nemo_sth->execute();
		   $line_id = ($nemo_sth->fetchrow_array())[0];
			$nemo_sth->finish();
		   if (defined $line_id) {
				$rev = 0;
				print "Found $line_name with id $line_id\n" if $debug;
		   }
		   elsif(defined $rev_line_name) {
				$nemo_sth = $nemo_dbh->prepare("SELECT line_id FROM line WHERE line_name = '$rev_line_name'");
				$nemo_sth->execute();
                                $line_id = ($nemo_sth->fetchrow_array())[0];
				$nemo_sth->finish();	
				if (defined $line_id) {
					$rev = 1;
					print "Found $rev_line_name (R) with id $line_id\n" if $debug;
				}
		    }
		    
		    if (!defined $line_id) {
			 	print "$rev_line_name and " if ($debug and $rev_line_name);
				print "$line_name not found.\n" if $debug;
				$skipped_rows++;
				next;
		    }

		    my $tablename = "port"."$port_number"."_".$str_interval;  # e.g. port80_hour
		    $nemo_sth = $nemo_dbh->prepare("SELECT COUNT(*) FROM $tablename WHERE line_id = '$line_id' AND timestamp = '$int_timestamp'");
		    $nemo_sth->execute();
		    my $num_rows = ($nemo_sth->fetchrow_array())[0];
			$nemo_sth->finish();
		    if ($num_rows == 0) {
				if ($rev == 0) {
					$nemo_sth = $nemo_dbh->prepare("INSERT INTO $tablename (line_id, timestamp, percent_out) VALUES ('$line_id', '$int_timestamp', '$percent_value')");
					$nemo_sth->execute();
					$nemo_sth->finish();
					print "Inserting percent_out for $line_name\n" if $debug;
				}
				elsif ($rev == 1) {
					$nemo_sth = $nemo_dbh->prepare("INSERT INTO $tablename (line_id, timestamp, percent_in) VALUES ('$line_id', '$int_timestamp', '$percent_value')");
					$nemo_sth->execute();
					$nemo_sth->finish();
					print "Inserting precent_in for $line_name\n" if $debug;
				}
				$inserted_rows++;
		    }
		    else {
				if ($rev == 0) {
					$nemo_sth = $nemo_dbh->prepare("UPDATE $tablename SET percent_out = '$percent_value' WHERE line_id = '$line_id' AND timestamp = '$int_timestamp'");
					$nemo_sth->execute();
					$nemo_sth->finish();
					print "Updating percent_out for $line_name\n" if $debug;
				}
				elsif ($rev == 1) {
					$nemo_sth = $nemo_dbh->prepare("UPDATE $tablename SET percent_in = '$percent_value' WHERE line_id = '$line_id' AND timestamp = '$int_timestamp'");
					$nemo_sth->execute();
					$nemo_sth->finish();
					print "Updating percent_in for $line_name\n" if $debug;
				}
				$updated_rows++;
		    }
		}
		$netflow_sth->finish();
    }
}
