CREATE TABLE net (
	net text PRIMARY KEY NOT NULL,
	description text
);

CREATE TABLE map (
	map_id text PRIMARY KEY NOT NULL,
	net text REFERENCES net (net) NOT NULL,
	coord_type text,
	bitmap_width integer,
	bitmap_height integer,
	bitmap_factor real,
	x1 integer,
	y1 integer,
	x2 integer,
	y2 integer,
	zoomlevel integer,
	mapurl text,
	"external" boolean DEFAULT false
);

CREATE TABLE location (
   location_id serial PRIMARY KEY,
   net text REFERENCES net (net),
   location_name text,
);

CREATE TABLE line (
	line_id serial PRIMARY KEY,
	line_type text,
	line_name text,
	from_loc integer REFERENCES location (location_id) NOT NULL,
	to_loc integer REFERENCES location (location_id) NOT NULL,
	net text
);

CREATE TABLE map_line (
	net text REFERENCES net (net) NOT NULL,
	map_id text NOT NULL,
	line_id integer REFERENCES line (line_id) ON DELETE CASCADE NOT NULL,
	from_date integer,
	to_date integer,
	PRIMARY KEY (net, map_id, line_id)
);

CREATE TABLE map_point (
	net text REFERENCES net (net) NOT NULL,
	map_id text NOT NULL,
	location_id integer REFERENCES location (location_id) ON DELETE CASCADE NOT NULL,
	point_type text,
   from_date integer,
   to_date integer,
   coord_type text,
   x integer,
   y integer,
	PRIMARY KEY (net, map_id, location_id)
);

CREATE TABLE equipment (
	eq_id text PRIMARY KEY NOT NULL,
	net text REFERENCES net (net),
	location_id integer REFERENCES location (location_id),
	eq_type text
);

CREATE TABLE equipment_address (
	ip_address text PRIMARY KEY NOT NULL,
	eq_id text REFERENCES equipment (eq_id) NOT NULL
);

CREATE TABLE statistic (
	stat_name text NOT NULL,
	timespan text NOT NULL,
	net text REFERENCES net (net) NOT NULL,
	stat_type text,
	stat_url text,
	statistic_table text,
	statistic_column1 text,
	statistic_column2 text,
	equipmentvalue_table text,
	equipmentvalue_column text,
	unit text,
	description text,
	restricted integer,
	PRIMARY KEY (stat_name, timespan)
);

CREATE TABLE conversion (
	stat_name text NOT NULL,
	interval_start integer NOT NULL,
	interval_end integer NOT NULL,
	colour text,
	size text,
	symbol_url text,
	label text,
	PRIMARY KEY (stat_name, interval_start, interval_end)
);

CREATE TABLE line_url (
	net text REFERENCES net (net) NOT NULL,
	line_id integer REFERENCES line (line_id) NOT NULL,
	link text NOT NULL,
	url_info text,
	PRIMARY KEY (net, line_id, link)
);

CREATE TABLE location_url (
	net text REFERENCES net (net) NOT NULL,
	location_id integer REFERENCES location (location_id) NOT NULL,
	link text NOT NULL,
	PRIMARY KEY (net, location_id, link)
);
