CREATE TABLE line_load_5min (
	line_id integer REFERENCES line (line_id) NOT NULL,
	timestamp integer NOT NULL,
	kbits_in bigint,
	kbits_out bigint,
	percent_in integer,
	percent_out integer,
	capacity bigint,
	PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX line_load_5min_timestamp_index ON
	line_load_5min (timestamp);

CREATE TABLE line_load_hour (
        line_id integer REFERENCES line (line_id) NOT NULL,
        timestamp integer NOT NULL,
        peak_in integer, 
        peak_out integer,
        avg_in integer, 
        avg_out integer,
        percent_peak_in integer, 
        percent_peak_out integer,
        percent_avg_in integer, 
        percent_avg_out integer,
        capacity integer,
        PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX line_load_hour_timestamp_index ON
        line_load_hour (timestamp);

CREATE TABLE line_load_day (
	line_id integer REFERENCES line (line_id) NOT NULL,
	timestamp integer NOT NULL,
	peak_in integer,
	peak_out integer,
	avg_in integer,
	avg_out integer,
	percent_peak_in integer,
	percent_peak_out integer,
	percent_avg_in integer,
	percent_avg_out integer,
	capacity integer,
	PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX line_load_day_timestamp_index ON
	line_load_day (timestamp);

CREATE TABLE line_load_week (
	line_id integer REFERENCES line (line_id) NOT NULL,
	timestamp integer NOT NULL,
	peak_in integer,
	peak_out integer,
	avg_in integer,
	avg_out integer,
	percent_peak_in integer,
	percent_peak_out integer,
	percent_avg_in integer,
	percent_avg_out integer,
	capacity integer,
	PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX line_load_week_timestamp_index ON
	line_load_week (timestamp);

CREATE TABLE line_load_month (
	line_id integer REFERENCES line (line_id) NOT NULL,
	timestamp integer NOT NULL,
	peak_in integer,
	peak_out integer,
	avg_in integer,
	avg_out integer,
	percent_peak_in integer,
	percent_peak_out integer,
	percent_avg_in integer,
	percent_avg_out integer,
	capacity integer,
	PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX line_load_month_timestamp_index ON
	line_load_month (timestamp);

CREATE TABLE port80_hour (
   line_id integer REFERENCES line (line_id) NOT NULL,
   timestamp integer NOT NULL,
	percent_in integer DEFAULT 0,
	percent_out integer DEFAULT 0,
   PRIMARY KEY (line_id, timestamp)
);

CREATE INDEX port80_hour_timestamp_index ON
        port80_hour (timestamp);

CREATE TABLE port25_hour (
        line_id integer REFERENCES line (line_id) NOT NULL,
        timestamp integer NOT NULL,
        percent_in integer DEFAULT 0,
        percent_out integer DEFAULT 0,
        PRIMARY KEY (line_id, timestamp)
);
  
CREATE INDEX port25_hour_timestamp_index ON
        port25_hour (timestamp);
        
CREATE TABLE port4662_hour (
        line_id integer REFERENCES line (line_id) NOT NULL,
        timestamp integer NOT NULL,
        percent_in integer DEFAULT 0,
        percent_out integer DEFAULT 0,
        PRIMARY KEY (line_id, timestamp)
);
  
CREATE INDEX port4662_hour_timestamp_index ON
        port4662_hour (timestamp);
        
CREATE TABLE port6881_hour (
        line_id integer REFERENCES line (line_id) NOT NULL,
        timestamp integer NOT NULL,
        percent_in integer DEFAULT 0,
        percent_out integer DEFAULT 0,
        PRIMARY KEY (line_id, timestamp)
);
  
CREATE INDEX port6881_hour_timestamp_index ON
        port6881_hour (timestamp);
        
CREATE TABLE port25_day (
    line_id integer REFERENCES line (line_id) NOT NULL,
    timestamp integer NOT NULL,
    percent_in integer DEFAULT 0,
    percent_out integer DEFAULT 0
);

CREATE INDEX port25_day_timestamp_index ON
        port25_day (timestamp);

CREATE TABLE port80_day (
    line_id integer REFERENCES line (line_id) NOT NULL,
    timestamp integer NOT NULL,
    percent_in integer DEFAULT 0,
    percent_out integer DEFAULT 0
);

CREATE INDEX port80_day_timestamp_index ON
        port80_day (timestamp);

CREATE TABLE port4662_day (
    line_id integer REFERENCES line (line_id) NOT NULL,
    timestamp integer NOT NULL,
    percent_in integer DEFAULT 0,
    percent_out integer DEFAULT 0
);

CREATE INDEX port4662_day_timestamp_index ON
        port4662_day (timestamp);

CREATE TABLE port6881_day (
    line_id integer REFERENCES line (line_id) NOT NULL,
    timestamp integer NOT NULL,
    percent_in integer DEFAULT 0,
    percent_out integer DEFAULT 0
);

CREATE INDEX port6881_day_timestamp_index ON
        port6881_day (timestamp);

CREATE TABLE eq_cpuload_5min (
	eq_id text REFERENCES equipment (eq_id) NOT NULL,
	timestamp integer NOT NULL,
	five_sec_load integer,
	one_min_load integer,
	five_min_load integer,
	PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_cpuload_5min_timestamp_index ON eq_cpuload_5min
	(timestamp);

CREATE TABLE eq_cpuload_hour (
	eq_id text REFERENCES equipment (eq_id) NOT NULL,
	timestamp integer NOT NULL,
   five_sec_load_peak integer,
   five_sec_load_avg integer, 
   one_min_load_peak integer, 
   one_min_load_avg integer,  
   five_min_load_peak integer,
   five_min_load_avg integer,
   PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_cpuload_hour_timestamp_index ON eq_cpuload_hour
        (timestamp);

CREATE TABLE eq_cpuload_day (
	eq_id text REFERENCES equipment (eq_id) NOT NULL,
	timestamp integer NOT NULL,
	five_sec_load_peak integer,
	five_sec_load_avg integer,
	one_min_load_peak integer,
	one_min_load_avg integer,
	five_min_load_peak integer,
	five_min_load_avg integer,
	PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_cpuload_day_timestamp_index ON eq_cpuload_day
	(timestamp);

CREATE TABLE point_cpuload_5min (
        point_id integer REFERENCES location (location_id) NOT NULL,
        timestamp integer NOT NULL,
        five_sec_load integer,
        one_min_load integer,
        five_min_load integer,
        PRIMARY KEY (point_id, timestamp)
);

CREATE INDEX point_cpuload_5min_timestamp_index ON 
	point_cpuload_5min (timestamp);

CREATE TABLE point_cpuload_hour (
        point_id integer REFERENCES location (location_id) NOT NULL,
        timestamp integer NOT NULL,
        five_sec_load_peak integer,
        five_sec_load_avg integer, 
        one_min_load_peak integer, 
        one_min_load_avg integer,  
        five_min_load_peak integer,
        five_min_load_avg integer, 
        PRIMARY KEY (point_id, timestamp)
);
  
CREATE INDEX point_cpuload_hour_timestamp_index ON
        point_cpuload_hour (timestamp);

CREATE TABLE point_cpuload_day (
	point_id integer REFERENCES location (location_id) NOT NULL,
	timestamp integer NOT NULL,
	five_sec_load_peak integer,
	five_sec_load_avg integer,
	one_min_load_peak integer,
	one_min_load_avg integer,
	five_min_load_peak integer,
	five_min_load_avg integer,
	PRIMARY KEY (point_id, timestamp)
);

CREATE INDEX point_cpuload_day_timestamp_index ON
	point_cpuload_day (timestamp);

CREATE TABLE eq_response_5min (
	eq_id text REFERENCES equipment (eq_id) NOT NULL,
	timestamp integer NOT NULL,
	median integer,
	min integer,
	max integer,
	average integer,
	packetloss integer,
	PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_response_5min_timestamp_index ON
	eq_response_5min (timestamp);

CREATE TABLE eq_response_hour (
        eq_id text REFERENCES equipment (eq_id) NOT NULL,
        timestamp integer NOT NULL,
        median integer,
        max integer,
        packetloss integer,
        PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_response_hour_timestamp ON
eq_response_hour(timestamp);

CREATE TABLE eq_response_day (
	eq_id text REFERENCES equipment (eq_id) NOT NULL,
	timestamp integer NOT NULL,
	median integer,
	max integer,
	packetloss float,
	PRIMARY KEY (eq_id, timestamp)
);

CREATE INDEX eq_response_day_timestamp ON
eq_response_5min(timestamp);

CREATE TABLE point_response_5min (
        point_id integer REFERENCES location (location_id) NOT NULL,
        timestamp integer NOT NULL,
        median integer,
        min integer,
        max integer,
        average integer,
        packetloss integer,
        PRIMARY KEY (point_id, timestamp)
);

CREATE INDEX point_response_5min_timestamp ON
point_response_5min (timestamp);

CREATE TABLE point_response_hour (
        point_id integer REFERENCES location (location_id) NOT NULL,
        timestamp integer NOT NULL,
        median integer,
        max integer,
        packetloss integer,
        PRIMARY KEY (point_id, timestamp)
);
  
CREATE INDEX point_response_hour_timestamp ON
point_response_hour (timestamp);

CREATE TABLE point_response_day (
	point_id integer REFERENCES location (location_id) NOT NULL,
	timestamp integer NOT NULL,
	median integer,
	max integer,
	packetloss float,
	PRIMARY KEY (point_id, timestamp)
);

CREATE INDEX point_response_day_timestamp ON
point_response_day(timestamp);

INSERT INTO net (net,description) VALUES ('uninett','Uninett AS geographical maps');

INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Line capacity (kbits/sec)', '5min', 'uninett', 'linesize', 'line_load_5min', 'capacity', 'capacity', NULL, NULL, 'Kbits/sec', 'Line capacity in Kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Line capacity (kbits/sec)', 'hour', 'uninett', 'linesize', 'line_load_hour', 'capacity', 'capacity', NULL, NULL, 'Kbits/sec', 'Line capacity in Kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Line capacity (kbits/sec)', 'day', 'uninett', 'linesize', 'line_load_day', 'capacity', 'capacity', NULL, NULL, 'Kbits/sec', 'Line capacity in Kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('WWW HTTP (port 80)', 'hour', 'uninett', 'linecolour', 'port80_hour', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of HTTP traffic out of total traffic', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('WWW HTTP (port 80)', 'day', 'uninett', 'linecolour', 'port80_day', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of HTTP traffic out of total traffic', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('SMTP mail (port 25)', 'hour', 'uninett', 'linecolour', 'port25_hour', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of SMTP traffic out of total traffic', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('SMTP mail (port 25)', 'day', 'uninett', 'linecolour', 'port25_day', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of SMTP traffic out of total traffic', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('eMule (port 4662)', 'hour', 'uninett', 'linecolour', 'port4662_hour', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of eMule traffic out of total traffic', NULL, 1);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('eMule (port 4662)', 'day', 'uninett', 'linecolour', 'port4662_day', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of eMule traffic out of total traffic', NULL, 1);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('BitTorrent (port 6881)', 'hour', 'uninett', 'linecolour', 'port6881_hour', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of BitTorrent traffic out of total traffic', NULL, 1);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('BitTorrent (port 6881)', 'day', 'uninett', 'linecolour', 'port6881_day', 'percent_in', 'percent_out', NULL, NULL, '%', 'Percentage of BitTorrent traffic out of total traffic', NULL, 1);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (percent)', '5min', 'uninett', 'linecolour', 'line_load_5min', 'percent_in', 'percent_out', NULL, NULL, '%', 'Peak line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (percent)', 'hour', 'uninett', 'linecolour', 'line_load_hour', 'percent_peak_in', 'percent_peak_out', NULL, NULL, '%', 'Peak line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (percent)', 'day', 'uninett', 'linecolour', 'line_load_day', 'percent_peak_in', 'percent_peak_out', NULL, NULL, '%', 'Peak line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (kbits/sec)', '5min', 'uninett', 'linecolour', 'line_load_5min', 'kbits_in', 'kbits_out', NULL, NULL, 'Kbits/sec', 'Peak line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (kbits/sec)', 'hour', 'uninett', 'linecolour', 'line_load_hour', 'peak_in', 'peak_out', NULL, NULL, 'Kbits/sec', 'Peak line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak line load (kbits/sec)', 'day', 'uninett', 'linecolour', 'line_load_day', 'peak_in', 'peak_out', NULL, NULL, 'Kbits/sec', 'Peak line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (percent)', '5min', 'uninett', 'linecolour', 'line_load_5min', 'percent_in', 'percent_out', NULL, NULL, '%', 'Average line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (percent)', 'hour', 'uninett', 'linecolour', 'line_load_hour', 'percent_avg_in', 'percent_avg_out', NULL, NULL, '%', 'Average line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (percent)', 'day', 'uninett', 'linecolour', 'line_load_day', 'percent_avg_in', 'percent_avg_out', NULL, NULL, '%', 'Average line load in percent', 'http://drift.uninett.no/stat-q/plot-all/#LINE#,#YEAR#-#MONTH#--#DAY#,hr,traffic', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (kbits/sec)', '5min', 'uninett', 'linecolour', 'line_load_5min', 'kbits_in', 'kbits_out', NULL, NULL, 'Kbits/sec', 'Average line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (kbits/sec)', 'hour', 'uninett', 'linecolour', 'line_load_hour', 'avg_in', 'avg_out', NULL, NULL, 'Kbits/sec', 'Average line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average line load (kbits/sec)', 'day', 'uninett', 'linecolour', 'line_load_day', 'avg_in', 'avg_out', NULL, NULL, 'Kbits/sec', 'Average line load in kbits/sec', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (5 sec period)', '5min', 'uninett', 'pointcolour', 'point_cpuload_5min', 'five_sec_load', NULL, 'eq_cpuload_5min', 'five_sec_load', '%', 'Average CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (5 sec period)', 'hour', 'uninett', 'pointcolour', 'point_cpuload_hour', 'five_sec_load_avg', NULL, 'eq_cpuload_hour', 'five_sec_load_avg', '%', 'Average CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (5 sec period)', 'day', 'uninett', 'pointcolour', 'point_cpuload_day', 'five_sec_load_avg', NULL, 'eq_cpuload_day', 'five_sec_load_avg', '%', 'Average CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (5 sec period)', '5min', 'uninett', 'pointcolour', 'point_cpuload_5min', 'five_sec_load', NULL, 'eq_cpuload_5min', 'five_sec_load', '%', 'Peak CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (5 sec period)', 'hour', 'uninett', 'pointcolour', 'point_cpuload_hour', 'five_sec_load_peak', NULL, 'eq_cpuload_hour', 'five_sec_load_peak', '%', 'Peak CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (5 sec period)', 'day', 'uninett', 'pointcolour', 'point_cpuload_day', 'five_sec_load_peak', NULL, 'eq_cpuload_day', 'five_sec_load_peak', '%', 'Peak CPU load busy percentage, last 5 secs', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (1 min period)', '5min', 'uninett', 'pointcolour', 'point_cpuload_5min', 'one_min_load', NULL, 'eq_cpuload_5min', 'one_min_load', '%', 'Average CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (1 min period)', 'hour', 'uninett', 'pointcolour', 'point_cpuload_hour', 'one_min_load_avg', NULL, 'eq_cpuload_hour', 'one_min_load_avg', '%', 'Average CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average CPU load (1 min period)', 'day', 'uninett', 'pointcolour', 'point_cpuload_day', 'one_min_load_avg', NULL, 'eq_cpuload_day', 'one_min_load_avg', '%', 'Average CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (1 min period)', '5min', 'uninett', 'pointcolour', 'point_cpuload_5min', 'one_min_load', NULL, 'eq_cpuload_5min', 'one_min_load', '%', 'Peak CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (1 min period)', 'hour', 'uninett', 'pointcolour', 'point_cpuload_hour', 'one_min_load_peak', NULL, 'eq_cpuload_hour', 'one_min_load_peak', '%', 'Peak CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Peak CPU load (1 min period)', 'day', 'uninett', 'pointcolour', 'point_cpuload_day', 'one_min_load_peak', NULL, 'eq_cpuload_day', 'one_min_load_peak', '%', 'Average CPU load busy percentage, last minute', 'http://drift.uninett.no/genplotg/plot-all?dataset=cpumem&filenames=#EQ#&datespec=#YEAR#-#MONTH#-#DAY#&res=raw&variables=busyPer', 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (median)', '5min', 'uninett', 'pointsize', 'point_response_5min', 'median', NULL, 'eq_response_5min', 'median', 'ms', 'Median response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (median)', 'hour', 'uninett', 'pointsize', 'point_response_hour', 'median', NULL, 'eq_response_hour', 'median', 'ms', 'Median response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (median)', 'day', 'uninett', 'pointsize', 'point_response_day', 'median', NULL, 'eq_response_day', 'median', 'ms', 'Median response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (max)', '5min', 'uninett', 'pointsize', 'point_response_5min', 'max', NULL, 'eq_response_5min', 'max', 'ms', 'Max response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (max)', 'hour', 'uninett', 'pointsize', 'point_response_hour', 'max', NULL, 'eq_response_hour', 'max', 'ms', 'Max response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Ping time (max)', 'day', 'uninett', 'pointsize', 'point_response_day', 'max', NULL, 'eq_response_day', 'max', 'ms', 'Max response time out of 20 packets', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average packetloss', '5min', 'uninett', 'pointcolour', 'point_response_5min', 'packetloss', NULL, 'eq_response_5min', 'packetloss', '%', 'Average packetloss in percent', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average packetloss', 'hour', 'uninett', 'pointcolour', 'point_response_hour', 'packetloss', NULL, 'eq_response_hour', 'packetloss', '%', 'Average packetloss in percent', NULL, 0);
INSERT INTO statistic (stat_name, timespan, net, stat_type, statistic_table, statistic_column1, statistic_column2, equipmentvalue_table, equipmentvalue_column, unit, description, stat_url, restricted) VALUES  ('Average packetloss', 'day', 'uninett', 'pointcolour', 'point_response_day', 'packetloss', NULL, 'eq_response_day', 'packetloss', '%', 'Average packetloss in percent', NULL, 0);

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('WWW HTTP (port 80)',
        70, 101, '178 0 0');

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('SMTP mail (port 25)',
        70, 101, '178 0 0');

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('eMule (port 4662)',
        70, 101, '178 0 0');

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('BitTorrent (port 6881)',
        70, 101, '178 0 0');

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak line load (percent)',
        70, 101, '178 0 0');


INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
	0, 4, '178 255 178');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
        5, 9, '25 229 102');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
        10, 29, '255 255 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
        30, 49, '255 204 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
        50, 69, '255 76 76');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average line load (percent)',
        70, 101, '178 0 0');
        
        
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (5 sec period)',
	0, 9, '0 199 72');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (5 sec period)',
        10, 29, '225 225 46');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (5 sec period)',
        30, 59, '225 174 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (5 sec period)',
        60, 101, '225 46 46');


INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (5 sec period)',
        0, 9, '0 199 72');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (5 sec period)',
        10, 29, '225 225 46');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (5 sec period)',
        30, 59, '225 174 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (5 sec period)',
        60, 101, '225 46 46');


INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (1 min period)',
        0, 9, '0 199 72');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (1 min period)',
        10, 29, '225 225 46');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (1 min period)',
        30, 59, '225 174 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Average CPU load (1 min period)',
        60, 101, '225 46 46');


INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (1 min period)',
        0, 9, '0 199 72');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (1 min period)',
        10, 29, '225 225 46');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (1 min period)',
        30, 59, '225 174 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES ('Peak CPU load (1 min period)',
        60, 101, '225 46 46');


INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
	('Ping time (median)', 0, 9, 8);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (median)', 10, 29, 10);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (median)', 30, 59, 12);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (median)', 60, 99, 14);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (median)', 100, 999, 16);

INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (max)', 0, 9, 8);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (max)', 10, 29, 10);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (max)', 30, 59, 12);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (max)', 60, 99, 14);
INSERT INTO conversion (stat_name, interval_start, interval_end, size) VALUES
        ('Ping time (max)', 100, 999, 16);

INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES
	('Average packetloss', 0, 4, '0 199 72');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES
	('Average packetloss', 5, 19, '225 225 46');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES
	('Average packetloss', 20, 64, '225 174 0');
INSERT INTO conversion(stat_name, interval_start, interval_end, colour) VALUES
	('Average packetloss', 65, 101, '225 46 46');
