/*
 * EquipmentTableModel.java
 *
 * Created on August 15, 2003, 11:10 AM
 */

import javax.swing.table.*;
import javax.swing.event.*;
import java.util.*;

/**
 * This class contains the tablemodel that is used in the StatisticDialog class
 * for displaying the detailed statistics for every piece of equipment. There
 * is one column for each type of statistic selected, plus one column for the
 * name of the equipment. There is one row for every piece of equipment at
 * the location. 
 * 
 * @author Gunnar Gauslaa Bergem
 */
public class EquipmentTableModel extends AbstractTableModel {
    private Vector eqNames;
    private Vector statValues;
    private Vector headers;
    
    /** Creates a new instance of CaseTableModel */
    public EquipmentTableModel() {
        statValues = new Vector();
        headers = new Vector();
        eqNames = new Vector();
        headers.add(0, "Equipment");
    }
    
    public String getColumnName(int column) {
        return (String)headers.elementAt(column);
    }
    
    public int getColumnCount() {
        return headers.size();
    }
    
    public int getRowCount() {
        return eqNames.size();
    }
    
    public void addStatisticColumn(Hashtable valueList, String title) {
        statValues.add(valueList);
        headers.addElement(title);
        
        // Add all the equipment names from the valueList to the first column if they're not already present
        for (Enumeration e = valueList.keys(); e.hasMoreElements(); ) {
            String key = (String)e.nextElement();
            if (!eqNames.contains(key)) {
                eqNames.addElement(key);
            }
        }
        Collections.sort(eqNames);
        fireTableStructureChanged();
        fireTableChanged(new TableModelEvent(this));
    }
    
    public void clearTable() {
        headers.removeAllElements();
        statValues.removeAllElements();
        eqNames.removeAllElements();
        headers.add(0, "Equipment");
    }
    
    public Object getValueAt(int row, int column) {
        try {
            if (column == 0) {
                // Return the name of the equipment
                return (String)eqNames.elementAt(row);
            }
            else {
                // Find the correct column
                Hashtable hash = (Hashtable)statValues.elementAt(column-1);
                // Return the value of the cell corresponding to the equipment key
                return (String)hash.get((String)eqNames.elementAt(row));
            }
        } catch (Exception e) {
        }
        return "";
    }
    
    public Class getColumnClass(int c) {
        return java.lang.String.class;
    }
    
    /**
     * Fires a tablemodel event depending on wheter the row is being added
     * or updated.
     * The tablemodel event makes sure the new data is displayed in the JTable.
     * @param addedRow true if the row is added, false if it is updated
     * @param index index of the row being added or updated
     */
    public void updateEquipment(boolean addedRow, int index) {
        if (addedRow) {
            // updates the number of rows in the model
            fireTableRowsInserted(index, index);
        }
        else {
            fireTableRowsUpdated(index, index);
        }
    }
}