/*
 * LineStatistic.java
 *
 * Created on July 4, 2003, 10:29 AM
 */

import java.awt.*;
import javax.swing.*;

/**
 * The LineStatistic class contains values such as colour and size for a line so
 * that it can be drawn correctly on the map.
 * 
 * @author Gunnar Gauslaa Bergem
 */
public class LineStatistic {
    private String statisticType;         // e.g. linecolour or linesize
    private String statisticDescription;  // description of the statistic
    private Color originColour;           // colour of the origin part of the line
    private Color destinationColour;      // colour of the destination part of the line
    private ImageIcon symbol;             // the graphic symbol (if any) of the line
    private int originSize;               // size of the origin part of the line
    private int destinationSize;          // size of the destination part of the line
    private String lineName;              // name of the line this statistic belongs to
    private int timestamp;                // UTC time coordinates indicating the time of measurement
    
    /** Creates a new instance of LineStatistic */
    public LineStatistic(String type, String description, String name, int timestamp) {
        statisticType = type;
        statisticDescription = description;
        lineName = name;
        this.timestamp = timestamp;
    }
    
    public LineStatistic(String type, String description, String name, int timestamp, Color orgColour, Color destColour) {
        this(type, description, name, timestamp);
        originColour = orgColour;
        destinationColour = destColour;
    }
    
    public LineStatistic(String type, String description, String name, int timestamp, int orgSize, int destSize) {
        this(type, description, name, timestamp);
        originSize = orgSize;
        destinationSize = destSize;
    }
    
    public String getLineName() {
        return lineName;
    }
    
    public Color getOriginColour() {
        return originColour;
    }
    
    public Color getDestinationColour() {
        return destinationColour;
    }
    
    public int getOriginSize() {
        return originSize;
    }
    
    public int getDestinationSize() {
        return destinationSize;
    }
    
    public String getType() {
        return statisticType;
    }
    
    public String getDescription() {
        return statisticDescription;
    }
    
    public int getTimestamp() {
        return timestamp;
    }
}
