/*
 * NemoUtils.java
 *
 * Created on July 5, 2002, 12:31 PM
 */

import java.awt.Component;
import javax.swing.JOptionPane;
import javax.swing.*;

/**
 * Class that contains integer constants representing the columns in the case
 * table and eventually other common information. Also has methods for
 * providing debug information.
 * 
 */
public class NemoUtils {
    public static final int ID_COL = 0;
    public static final int OPSTATE_COL = 1;
    public static final int ADMSTATE_COL = 2;
    public static final int PRI_COL = 3;
    public static final int AGE_COL = 4;
    public static final int DOWNTIME_COL = 5;
    public static final int UPDATED_COL = 6;
    public static final int ENTITY_COL = 7;
    public static final int PORT_COL = 8;
    public static final int DESCRIPTION_COL = 9;
    public static final int NUM_COLUMNS = 10;
    
    public static final int DAY_AXIS = 1;
    public static final int MONTH_AXIS = 2;
    public static final int YEAR_AXIS = 3;
    
    // Number of minutes in each possible time step
    public static final int FIVEMIN_STEP = 5;
    public static final int HOUR_STEP = 60;
    public static final int DAY_STEP = 1440;

    private static boolean debugging = false;
    private static JFrame debugFrame;
    private static JScrollPane scrollPane;
    private static JTextArea textArea;

    /** Creates a new instance of NemoUtils */
    public NemoUtils() {
    }
    
    public static void showErrorMessage(String message, Component frame) {
        JOptionPane.showMessageDialog(frame, message, "Error", JOptionPane.ERROR_MESSAGE);
    }

    public static int distance(int x1, int y1, int x2, int y2) {
	int result = (int)(Math.sqrt(Math.pow((x2-x1), 2) + Math.pow((y2-y1), 2)));
	return result;
    }

    public static void debug(String message) {
	if (debugging && textArea != null) {
	    //System.err.println(message);
	    textArea.append(message+"\n");
	    JScrollBar scrollBar = scrollPane.getVerticalScrollBar();
	    scrollBar.setValue(scrollBar.getMaximum());
	}
    }

    public static void setDebugging(boolean flag) {
	if (flag) {
	    debugging = true;
	    debugFrame = new JFrame("NEMO debugger");
	    debugFrame.setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
	    textArea = new JTextArea(25, 50);
	    textArea.setEditable(false);
	    scrollPane = new JScrollPane(textArea);
	    debugFrame.getContentPane().add(scrollPane);
	    debugFrame.setLocation(550, 50);
	    debugFrame.pack();
	    debugFrame.setVisible(true);
	}
	else {
	    debugging = false;
	    debugFrame.setVisible(false);
	    debugFrame.dispose();
	}
    }
}
