/*
 * NetworkElement.java
 *
 * Created on July 17, 2002, 10:29 AM
 */

import javax.swing.*;
import java.util.*;
import java.awt.*;

/**
 * The NetworkElement class contains the name of the network it represents, and the list of
 * maps and statistics available in it. It keeps track of the currently selected map
 * and statistics.
 * 
 * @author Gunnar Gauslaa Bergem
 */
public class NetworkElement {
    private String networkName;  // name of this network (unique)
    private String description;  // description of the network
    private DefaultListModel mapList;  // all available maps in this network
    private DefaultListModel statisticList;  // all available statistics in this network
    private DefaultListModel currentStatistics;  // list of currently selected statistics
    private MapElement currentMap;  // the currently selected map
    
    /** Creates a new instance of NetworkElement */
    public NetworkElement(String name, String description) {
        networkName = name;
        this.description = description;
        mapList = new DefaultListModel();
        statisticList = new DefaultListModel();
        currentStatistics = new DefaultListModel();
    }
    
    public String getNetworkName() {
        return networkName;
    }
    
    public void setCurrentMap(MapElement mapElement) {
        currentMap = mapElement;
    }
    
    public MapElement getCurrentMap() {
        return currentMap;
    }
    
    public void setMapList(DefaultListModel maps) {
        mapList = maps;
    }
    
    public DefaultListModel getMapList() {
        return mapList;
    }
    
    public void setStatisticList(DefaultListModel statistics) {
        statisticList = statistics;
    }
    
    public DefaultListModel getStatisticList() {
        return statisticList;
    }
    
    public void addStatistic(StatisticElement statElement) {
        currentStatistics.addElement(statElement);
    }
    
    public void removeAllStatistics() {
        currentStatistics.removeAllElements();
    }
    
    public DefaultListModel getCurrentStatistics() {
        return currentStatistics;
    }
    
    public Vector getStepSizes() {
        Vector stepSizes = new Vector();
        
        for (int i = 0; i < currentStatistics.size(); i++) {
            StatisticElement statElement = (StatisticElement)currentStatistics.elementAt(i);
            Vector statSteps = statElement.getStepSizes();
            for (int j = 0; j < statSteps.size(); j++) {
                if (!stepSizes.contains(statSteps.elementAt(j))) {
                    stepSizes.addElement(statSteps.elementAt(j));
                }
            }
        }
        return stepSizes;
    }
    
    public MapElement getMapAtPoint(Point point) {
        MapElement biggestMap = null;
        int biggestSize = 0;
        
        for (int i = 0; i < mapList.size(); i++) {
            MapElement mapElement = (MapElement)mapList.elementAt(i);
            if (mapElement.contains(point) && (mapElement.getRegionSize() > biggestSize) && !mapElement.isSuperRegion()) {
                biggestMap = mapElement;
                biggestSize = mapElement.getRegionSize();
            }
        }
        if (biggestMap == null) {
            for (int i = 0; i < mapList.size(); i++) {
               MapElement mapElement = (MapElement)mapList.elementAt(i);
                if (mapElement.contains(point) && mapElement.isSuperRegion()) {
                    biggestMap = mapElement;
                }
            }
        }
        return biggestMap;
    }
    
    public String toString() {
        return networkName;
    }
    
    /*
    public boolean equals(Object anObject) {
        String otherNetworkName = null;
        boolean isEqual = false;
        if (anObject != null && anObject.getClass().getName().compareTo("NetworkElement") == 0) {
            otherNetworkName = ((NetworkElement)anObject).getNetworkName();
            if (networkName.compareTo(otherNetworkName) == 0) {
                isEqual = true;
            }
        }
        return isEqual;
    }
    */
}
