/*
 * StatisticDialog.java
 *
 * Created on August 14, 2003, 2:04 PM
 */

import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import javax.jnlp.*;
import java.util.*;
import java.net.*;

/**
 * The StatisticDialog class is a GUI representation of the detailed statistics
 * for a point or a line that appears when the user clicks on the element.
 * 
 * @author Gunnar Gauslaa Bergem
 */
public class StatisticDialog extends javax.swing.JDialog {
    EquipmentTableModel tableModel;

    /** Creates new form StatisticDialog */
    public StatisticDialog(java.awt.Frame parent, boolean modal, String title, Vector measureStrings, Vector dateStrings) {
        super(parent, modal);
        setTitle(title);
        initComponents();
        setMeasureLabels(measureStrings, dateStrings);
        tableModel = new EquipmentTableModel();
        JTable table = new JTable(tableModel);
        table.setPreferredScrollableViewportSize(new Dimension(400, 80));
        JScrollPane stat_scrollPane = new JScrollPane(table);
        statistics_panel.add(stat_scrollPane, BorderLayout.CENTER);
        closeDialog_button.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closeDialog_buttonActionPerformed(evt);
            }
        });
        pack();
    }



    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        mainDialog_panel = new javax.swing.JPanel();
        linkAndButton_panel = new javax.swing.JPanel();
        closeButton_panel = new javax.swing.JPanel();
        closeDialog_button = new javax.swing.JButton();
        link_pane = new javax.swing.JEditorPane();
        statistics_panel = new javax.swing.JPanel();
        measurePoints_panel = new javax.swing.JPanel();
        measure1_panel = new javax.swing.JPanel();
        measure1_label = new javax.swing.JLabel();
        date1_label = new javax.swing.JLabel();
        measure2_panel = new javax.swing.JPanel();
        measure2_label = new javax.swing.JLabel();
        date2_label = new javax.swing.JLabel();
        link_scrollPane = new javax.swing.JScrollPane(link_pane);

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });
	
	link_pane.setEditable(false);
	link_pane.setContentType("text/html");
	link_pane.setPreferredSize(new Dimension(400, 240));
        link_pane.addHyperlinkListener(new HyperlinkListener () {
            public void hyperlinkUpdate(final HyperlinkEvent e) {
                if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
                    try {
                        URL url = e.getURL();
                        BasicService bs = (BasicService)ServiceManager.lookup("javax.jnlp.BasicService");
                        bs.showDocument(url);
		    } catch (Exception ex) {
		    }
		}
            }
        });
        mainDialog_panel.setLayout(new java.awt.BorderLayout());

        mainDialog_panel.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(5, 5, 5, 5)));
        linkAndButton_panel.setLayout(new java.awt.BorderLayout());

        closeDialog_button.setText("Close");
        closeButton_panel.add(closeDialog_button);

        linkAndButton_panel.add(closeButton_panel, java.awt.BorderLayout.SOUTH);

        linkAndButton_panel.add(link_scrollPane, java.awt.BorderLayout.CENTER);

        mainDialog_panel.add(linkAndButton_panel, java.awt.BorderLayout.CENTER);

        statistics_panel.setLayout(new java.awt.BorderLayout());

        mainDialog_panel.add(statistics_panel, java.awt.BorderLayout.NORTH);

        measurePoints_panel.setLayout(new java.awt.GridLayout(2, 1, 0, 5));

        measurePoints_panel.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(5, 5, 5, 5)));
        measure1_panel.setLayout(new java.awt.BorderLayout(5, 0));

        measure1_label.setFont(new java.awt.Font("Dialog", 0, 12));
        measure1_label.setText("Measure point for Line load (percent):");
        measure1_panel.add(measure1_label, java.awt.BorderLayout.WEST);

        date1_label.setFont(new java.awt.Font("Dialog", 0, 14));
        date1_label.setText("20:45:17 22.07.2003");
        measure1_panel.add(date1_label, java.awt.BorderLayout.EAST);

        measurePoints_panel.add(measure1_panel);

        measure2_panel.setLayout(new java.awt.BorderLayout(5, 0));

        measure2_label.setFont(new java.awt.Font("Dialog", 0, 12));
        measure2_label.setText("Measure point for Line capacity (Kbits/sec):");
        measure2_panel.add(measure2_label, java.awt.BorderLayout.WEST);

        date2_label.setFont(new java.awt.Font("Dialog", 0, 14));
        date2_label.setText("20:45:17 22.07.2003");
        measure2_panel.add(date2_label, java.awt.BorderLayout.EAST);

        measurePoints_panel.add(measure2_panel);

        mainDialog_panel.add(measurePoints_panel, java.awt.BorderLayout.SOUTH);

        getContentPane().add(mainDialog_panel, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents

    private void closeDialog_buttonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_close_buttonActionPerformed
        // Add your handling code here:
        setVisible(false);
        dispose();
    }//GEN-LAST:event_close_buttonActionPerformed

    /** Closes the dialog */
    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        setVisible(false);
        dispose();
    }//GEN-LAST:event_closeDialog

    public void setMeasureLabels(Vector measureStrings, Vector dateStrings) {
        if (measureStrings.size() > 0 && dateStrings.size() > 0) {
            measure1_label.setText((String)measureStrings.elementAt(0));
            date1_label.setText((String)dateStrings.elementAt(0));
            measure1_panel.setVisible(true);
        }
        else {
            measure1_panel.setVisible(false);
        }
        if (measureStrings.size() > 1 && dateStrings.size() > 1) {
            measure2_label.setText((String)measureStrings.elementAt(1));
            date2_label.setText((String)dateStrings.elementAt(1));
            measure2_panel.setVisible(true);
        }
        else {
            measure2_panel.setVisible(false);
        }
    }

    public void addStatisticColumn(Hashtable valueList, String title) {
        tableModel.addStatisticColumn(valueList, title);
        pack();
    }

    public void addURLlist(String linkContent) {
	String htmlPrefix = "<html><head></head><body><h3>Links</h3>\n";
	String htmlSuffix = "</body></html>";
	link_pane.setText(htmlPrefix+linkContent+htmlSuffix);
    }

    class URLlistener implements ActionListener {
        private URL url;

        public URLlistener(URL url) {
            this.url = url;
        }
        public void actionPerformed(ActionEvent e) {
            try {
                BasicService bs = (BasicService)ServiceManager.lookup("javax.jnlp.BasicService");
                bs.showDocument(url);
            } catch(UnavailableServiceException ue) {
                System.err.println("Browser service not available.\n");
            }
            //setVisible(false);
            //dispose();
        }
    }

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel measure2_panel;
    private javax.swing.JPanel closeButton_panel;
    private javax.swing.JButton closeDialog_button;
    private javax.swing.JPanel linkAndButton_panel;
    private javax.swing.JLabel date2_label;
    private javax.swing.JPanel measurePoints_panel;
    private javax.swing.JLabel measure1_label;
    private javax.swing.JPanel statistics_panel;
    private javax.swing.JEditorPane link_pane;
    private javax.swing.JLabel measure2_label;
    private javax.swing.JPanel mainDialog_panel;
    private javax.swing.JLabel date1_label;
    private javax.swing.JPanel measure1_panel;
    private javax.swing.JScrollPane link_scrollPane;
    // End of variables declaration//GEN-END:variables
}
